@@ -95,7 +95,7 @@ from CedarBackup3.actions.validate import executeValidate
 from CedarBackup3.config import Config
 from CedarBackup3.customize import customizeOverrides
 from CedarBackup3.peer import RemotePeer
-from CedarBackup3.release import AUTHOR, COPYRIGHT, DATE, EMAIL, VERSION
+from CedarBackup3.release import AUTHOR, EMAIL, VERSION
 from CedarBackup3.util import (
     Diagnostics,
     DirectedGraph,
@@ -1074,10 +1074,10 @@ def _version(fd=sys.stdout):
     *Note:* The ``fd`` is used rather than ``print`` to facilitate unit testing.
     """
     fd.write("\n")
-    fd.write(" Cedar Backup version %s, released %s.\n" % (VERSION, DATE))
+    fd.write(" Cedar Backup version %s.\n" % VERSION)
     fd.write("\n")
-    fd.write(" Copyright (c) %s %s <%s>.\n" % (COPYRIGHT, AUTHOR, EMAIL))
-    fd.write(" See CREDITS for a list of included code and other contributors.\n")
+    fd.write(" Copyright (c) %s <%s>.\n" % (AUTHOR, EMAIL))
+    fd.write(" See NOTICE for a list of included code and other contributors.\n")
     fd.write(" This is free software; there is NO warranty.  See the\n")
     fd.write(" GNU General Public License version 2 for copying conditions.\n")
     fd.write("\n")
